---
name: "\U0001F41B Bug report"
about: Did something not work out as expected? Let us know!
title: ''
labels: ''
assignees: ''

---

<!-- 
Please read.

Before posting, please be sure to review whether your issue matches the description of a known regression by using [this](https://github.com/Azure/azure-functions-durable-python/issues?q=is%3Aissue+is%3Aopen+label%3Aknown-regression) query.

If your issue corresponds to a known regression, please try the suggested workarounds listed in the issue before filing an issue. Thanks!
-->
🐛 **Describe the bug**
> A clear and concise description of what the bug is. 

🤔 **Expected behavior**
> What should have happened?

☕ **Steps to reproduce**
> What Durable Functions patterns are you using, if any?
> Any minimal reproducer we can use?
> Are you running this locally or on Azure? 

⚡**If deployed to Azure**
> We have access to a lot of telemetry that can help with investigations. Please provide as much of the following information as you can to help us investigate!

- **Timeframe issue observed**:
- **Function App name**:
- **Function name(s)**:
- **Azure region**:
- **Orchestration instance ID(s)**:
- **Azure storage account name**:

> If you don't want to share your Function App or storage account name GitHub, please at least share the orchestration instance ID. Otherwise it's extremely difficult to look up information.
